@@ -1,5 +1,23 @@
+import pkg_resources
 import requests
 import json
+from distutils.version import StrictVersion
+
+this_version = pkg_resources.get_distribution('mattuni').version
+
+# https://stackoverflow.com/a/27239645/6596010
+def versions(package_name):
+    url = "https://pypi.org/pypi/%s/json" % (package_name,)
+    data = json.load(requests.get(url).text)
+    versions = data["releases"].keys()
+    versions.sort(key=StrictVersion)
+    return versions
+
+online_versions = versions("mattuni")
+latest_version = online_versions[len(online_versions)-1]
+if (this_version != latest_version):
+    print(f"WARNING: You are using mattuni {this_version} but the latest version is {latest_version}. In the terminal use `python -m pip install mattuni --upgrade` to update.")
+
 _ran_x_times = []
 def send_answer(question_number,answer):
     print()
